@@ -66,6 +66,7 @@ FILE *logfile = NULL;
 
 int mode = UNDEFINED;
 char var[256] = {0,};
+char var1[256] = {0,};
 char scra[256] = {0,};
 
 extern int fixassy();
@@ -459,6 +460,9 @@ int main(int argc, char **argv)
   var[0] = 0;
   fpnt = fhead;
   ftail = fhead;
+
+  if(!fhead) exit(0); /* Empty file. */
+
   while(ftail->next) ftail = ftail->next;
   fprev = NULL;
   while (fpnt)
@@ -495,13 +499,13 @@ int main(int argc, char **argv)
 	  strncmp(fpnt->text,"\t.long",6) == 0)
 	{
 	  int fixflag = 0;
-	  strcpy(var, fpnt->text+7);
-	  var[strlen(var)-1] = 0; /* add trailing NULL */
+	  strcpy(var1, fpnt->text+7);
+	  var1[strlen(var1)-1] = 0; /* add trailing NULL */
 
 	  /* We must also handle the case of _foo+3 or _foo-3 */
-	  cp = strchr(var, '+');
+	  cp = strchr(var1, '+');
 	  if(cp) *cp =0;
-	  cp = strchr(var, '-');
+	  cp = strchr(var1, '-');
 	  if(cp) *cp =0;
 
 #ifdef IMPLIED_IMPORT
@@ -509,10 +513,10 @@ int main(int argc, char **argv)
 	    char * cpnt;
 	    /* Check to see if this is a simple constant.  If so, then
 	       pass on it */
-	    cpnt = var;
+	    cpnt = var1;
 	    while(*cpnt && *cpnt >= '0' && *cpnt <= '9') cpnt++;
 	    
-	    if((var[0] == '0' && var[1] == 'x') || *cpnt == 0) {
+	    if((var1[0] == '0' && var1[1] == 'x') || *cpnt == 0) {
 	      fprev = fpnt;
 	      fpnt = fpnt->next;
 	      continue;
@@ -523,7 +527,7 @@ int main(int argc, char **argv)
 	  gpnt = gdhead; /* See if this is an exported symbol */
 	  while (gpnt)
 	    {
-	      if (strcmp(var, gpnt->name) == 0)
+	      if (strcmp(var1, gpnt->name) == 0)
 		{
 		  fixflag = 1;
 		  break;
@@ -532,10 +536,10 @@ int main(int argc, char **argv)
 	    };
 	  if (!fixflag){
 #ifdef IMPLIED_IMPORT
-	    if(strncmp(var,"__GOT_",6) != 0){
+	    if(strncmp(var1,"__GOT_",6) != 0){
 	      spnt = shead; /* List of static variables */
 	      while (spnt){
-		if (strcmp(var, spnt->name) == 0)
+		if (strcmp(var1, spnt->name) == 0)
 		  break;
 		spnt = spnt->next;
 	      };
@@ -543,7 +547,7 @@ int main(int argc, char **argv)
 		gpnt = gfhead;  /* Global function list */
 		while (gpnt)
 		  {
-		    if (strcmp(var, gpnt->name) == 0) break;
+		    if (strcmp(var1, gpnt->name) == 0) break;
 		    gpnt = gpnt->next;
 		  };
 		
@@ -551,21 +555,21 @@ int main(int argc, char **argv)
 		  gpnt = gihead;  /* Ignore list */
 		  while (gpnt)
 		    {
-		      if (strcmp(var, gpnt->name) == 0) break;
+		      if (strcmp(var1, gpnt->name) == 0) break;
 		      gpnt = gpnt->next;
 		    };
 		};
 		if(!gpnt) fixflag = 1;
 	      };
 #ifdef DEBUG_IMPLIED
-	      if(fixflag) send_log('i',var);
+	      if(fixflag) send_log('i',var1);
 #endif
 	    };
 #else
 	    gpnt = gphead; /* See if this is an imported symbol */
 	    while (gpnt)
 	      {
-		if (strcmp(var, gpnt->name) == 0)
+		if (strcmp(var1, gpnt->name) == 0)
 		  {
 		    fixflag = 1;
 		    break;
@@ -612,7 +616,7 @@ int main(int argc, char **argv)
 		ftail = ftmp;
 	      };
 	      	      
-	      sprintf(scra, "\t.long __GOT_%s\n",var);
+	      sprintf(scra, "\t.long __GOT_%s\n",var1);
 	      ftmp = xmalloc(sizeof(LINE));
 	      ftmp->text = xstrdup(scra);
 	      ftmp->next = NULL;
