@@ -148,20 +148,27 @@ void main (int argc, char **argv)
 	sprintf(jump_read,"%s%sjump.log",filedir?filedir:"",filedir?"/":"");
 
 	if (access(jump_read, R_OK))
-		die ("Cannot open `%s' for reading\n", jump_read);
-
-	if (call==jump_funcs) {
-		sprintf(jump_write,"%s%sjump.funcs",filedir?filedir:"",filedir?"/":"");
-		xsystem (GREP " ' T ' %s>%s",jump_read,jump_write);
-		if (!extract_only && !(jumpfuncs = fopen (jump_write, "r")))
-			die ("Can't open `%s' file for reading\n", jump_write);
-	} else {
-		sprintf(jump_write,"%s%sjump.vars",filedir?filedir:"",filedir?"/":"");
-		xsystem (GREP " -v ' T ' %s>%s",jump_read,jump_write);
-		if (!extract_only && !(jumpvars = fopen (jump_write, "r")))
-			die ("Can't open `%s' file for reading\n", jump_write);
-	}
-	}
+	  {
+	    fprintf(stderr,"Warning - cannot open `%s' for reading\n", jump_read);
+	    if (call==jump_funcs)
+	      sprintf(jump_write,"%s%sjump.funcs",filedir?filedir:"",filedir?"/":"");
+	    else
+	      sprintf(jump_write,"%s%sjump.vars",filedir?filedir:"",filedir?"/":"");
+	    xsystem("rm -f %s;touch %s", jump_write, jump_write);
+	  } else {
+	    if (call==jump_funcs) {
+	      sprintf(jump_write,"%s%sjump.funcs",filedir?filedir:"",filedir?"/":"");
+	      xsystem (GREP " ' T ' %s>%s;true",jump_read,jump_write);
+	      if (!extract_only && !(jumpfuncs = fopen (jump_write, "r")))
+		die ("Can't open `%s' file for reading\n", jump_write);
+	    } else {
+	      sprintf(jump_write,"%s%sjump.vars",filedir?filedir:"",filedir?"/":"");
+	      xsystem (GREP " -v ' T ' %s>%s;true",jump_read,jump_write);
+	      if (!extract_only && !(jumpvars = fopen (jump_write, "r")))
+		die ("Can't open `%s' file for reading\n", jump_write);
+	    }
+	  }
+      }
      if (extract_only) return;
 
      if (jump_read) xfree(jump_read);
@@ -291,7 +298,7 @@ void main (int argc, char **argv)
 		fprintf (stderr, "WARNING: Old style library. Following values may be incorrect\n");
 	    if (current_got_size)
 		 fprintf (stderr,"\tGlobal Offset Table size is"
-			  HEX_AND_DEC(current_got_size - jump_table_size + 8L));
+			  HEX_AND_DEC(current_got_size - jump_table_size + 8));
 	    else
 		 fprintf (stderr,"\tUnable to determine GOT size\n");
 		 fprintf (stderr,"\tJump Table size is"
